json_extract_string

Function json_extract_string 

pub fn json_extract_string<J: JsonOrNullableJsonOrJsonbOrNullableJsonb + SingleValue, json, text>(
    json: json,
    text: text,
) -> json_extract_string<J, json, text>
where json: AsExpression<J>, text: AsExpression<Text>,
Available on crate feature __sqlite-shared only.
Extracts a text value from a well-formed JSON document at the given path.

Returns NULL if the path does not exist in the JSON document, or if the value at that path is a JSON null.

To extract other types, use:

This function requires at least SQLite 3.9 or newer.

Example


let json = json!({"a": "xyz"});
let result = diesel::select(json_extract_string::<Json, _, _>(json, "$.a"))
    .get_result::<Option<String>>(connection)?;
assert_eq!(Some("xyz".to_string()), result);

let json = json!({"a": 42});
let result = diesel::select(json_extract_string::<Json, _, _>(json, "$.a"))
    .get_result::<Option<String>>(connection)?;
assert_eq!(Some("42".to_string()), result);

let result = diesel::select(json_extract_string::<Nullable<Json>, _, _>(None::<Value>, "$.a"))
    .get_result::<Option<String>>(connection)?;
assert!(result.is_none());

let json = json!({"a": "xyz"});
let result = diesel::select(json_extract_string::<Json, _, _>(json, "$.x"))
    .get_result::<Option<String>>(connection)?;
assert!(result.is_none());